@@ -11,11 +11,6 @@ logging.getLogger('s3transfer').setLevel(logging.CRITICAL)
 my_logger = logger.logger('ocr')
 
 
-def i_am_also_here():
-    print('i am here')
-
-
-
 class MLModel(metaclass=ABCMeta):
     def __init__(self, model_name, config, model_id=None):
         self.model_name = model_name
